# cfbyvgt - Cost Function by Gia Tue Vu

This library implements **Cost Function** for Machine Learning.
It is simple and easy to use, especially for Linear Regression.
This library is mainly for beginners.
This is also my second library. Hope you enjoy it.
## Installation

```sh
pip install cfbyvgt
